@@ -10,7 +10,7 @@ import click
 
 import re
 from . import questions
-'import youtube_dl
+import youtube_dl
 from rich.progress import Progress
 
 from rich import print
